@@ -16,4 +16,15 @@ FILE_MAP = {
             'compositing':'comp',
         }
 LOGIN_NAME = os.getenv("LOGIN_NAME", "email")
-TEMPLATE_FILES_DIR =os.path.join(os.path.dirname(__file__), 'template_files')
\ No newline at end of file
+TEMPLATE_FILES_DIR =os.path.join(os.path.dirname(__file__), 'template_files')
+
+ENABLE_JOB_QUEUE = os.getenv("ENABLE_JOB_QUEUE", "False").lower() == "true"
+ENABLE_JOB_QUEUE_REMOTE = (
+    os.getenv("ENABLE_JOB_QUEUE_REMOTE", "False").lower() == "true"
+)
+
+KEY_VALUE_STORE = {
+    "host": os.getenv("KV_HOST", "localhost"),
+    "port": os.getenv("KV_PORT", "6379"),
+}
+KV_JOB_DB_INDEX = 7
\ No newline at end of file
